@@ -5,11 +5,11 @@
 #' Given a graph object of class `causact_graph`, create collections of nodes that should be repeated i.e. represent multiple instances of a random variable, random vector, or random matrix.  When nodes are on more than one plate, graph rendering will treat each unique combination of plates as separate plates.
 #' @param graph a graph object of class `dgr_graph` created using `dag_create()`.
 #' @param descr a longer more descriptive label for the cluster/plate.
-#' @param label a short character string to use as an index.
+#' @param label a short character string to use as an index.  Any `.` in the names is automatically replaced by `_` for interoperability with Python.
 #' @param nodeLabels a character vector of node labels or descriptions to include in the list of nodes.
 #' @param data a vector representing the categorical data whose unique values become the plate index.  To use with `addDataNode = TRUE`, this vector should represent observations of a variable that can be coerced to a factor.
 #' @param addDataNode a logical value.  When `addDataNode = TRUE`, the code attempts to add a node of observed data that is used as an index for extracting the correct parameter from parent nodes that are on the newly created plate.  Verify the graphical model using `dag_render()` to ensure correct behavior.
-#' @param rhs Optional `rhs` expression for when `addDataNode = TRUE`.  This can be either a greta distribution such as `uniform, normal, lognormal, bernoulli,` etc. or an R expression. Greta distribution arguments are optional.  Valid values include `normal(mu,sigma)`,`greta::normal`, `normal`, and `normal(6,2)`.  R computation/expression examples include `alpha+beta*x` or `ilogit(alpha + gamma + beta)`.  If a distribution is given, this is a random/stochastic node, if a formula is given it is a deterministic node once given the values of its parents.  Quotes should not be used as all function/computations should consist of R objects, functions, and constants.
+#' @param rhs Optional `rhs` expression for when `addDataNode = TRUE`.  This can be either a  distribution such as `uniform, normal, lognormal, bernoulli,` etc. or an R expression. Distribution arguments are optional.  Valid values include `normal(mu,sigma)`, `normal`, and `normal(6,2)`.  R computation/expression examples include `alpha+beta*x`.  If a distribution is given, this is a random/stochastic node, if a formula is given it is a deterministic node once given the values of its parents.  Quotes should not be used as all function/computations should consist of R objects, functions, and constants.
 #' @return an expansion of the input `causact_graph` object with an added plate representing the repetition of `nodeLabels` for each unique value of `data`.
 #' @examples
 #' # single plate example
@@ -61,6 +61,7 @@
 #' @importFrom dplyr mutate
 #' @importFrom rlang enquo get_expr UQ
 #' @importFrom utils head
+#' @importFrom lifecycle badge
 #' @export
 
 dag_plate <- function(graph,
@@ -99,6 +100,10 @@ dag_plate <- function(graph,
   ## for plates, the observed node is added automatically
   rhsExpr = rlang::enexpr(rhs) ##distribution or formula
 
+  ### replace . with hyphens for interoperability w/ Python
+  label = make_unique_No_periods(label)
+  nodeLabels = make_unique_No_periods(nodeLabels)
+
   ### get nodeIDS for enterned node labels
   ### node labels can be labels, descr, or data
   nodeIDS = findNodeID(graph,nodeLabels)
